package de.tudarmstadt.maki.simonstrator.api.component.privacy;

import java.util.ArrayList;
import java.util.List;

import de.tudarmstadt.maki.simonstrator.api.util.XMLConfigurableConstructor;

public class PrivacyLevel implements Comparable<PrivacyLevel> {
	public static final PrivacyLevel NO_PRIVACY = new PrivacyLevel(0);
	public static final List<PrivacyLevel> PRIVACY_LEVELS = new ArrayList<>();

	private static int staticID = 0;

	private final int id;
    private double imprecisionAreaRadius;

	@XMLConfigurableConstructor({ "imprecision" })
	public PrivacyLevel(double pImprecisionAreaRadius) {
		synchronized (PrivacyLevel.class) {
			id = staticID++;
		}
        imprecisionAreaRadius = pImprecisionAreaRadius;
    }

    public int getId() {
        return id;
    }

    public double getImprecisionAreaRadius() {
        return imprecisionAreaRadius;
    }

    @Override
    public int hashCode() {
        return id;
    }

    @Override
    public boolean equals(Object pObj) {
        if (pObj instanceof PrivacyLevel) {
            return ((PrivacyLevel) pObj).id == id;
        }
        return false;
    }

	@Override
	public int compareTo(PrivacyLevel pArg0) {
		return Double.compare(imprecisionAreaRadius, pArg0.getImprecisionAreaRadius());
	}
}
